# Save the current working directory.
saveWd <- getwd()

# Move to the Documents\AutoboxR directory.
setwd("~/AutoboxR")

# Load the library.
library(autobox)

# Initialize the autobox package.
autoboxInitPackage()

# Set the S_5 values.
dblHistoricalValues_S_5 <- c(
 5,1.6863,15.65859,12.64733,20.71753,34.20801,46.61443,38.06243,62.63438, 
 11.08147,39.50784,36.01477,13.37003,32.88305,13.61093,9.39516,6.98614, 
 2.52947,8.91335,9.39516,39.86919,51.79381,37.33973,7.46795,10.59966, 
 5.66118,4.93848,39.50784,2.77037,15.05634,41.3146,14.45409,0, 
 55.04598,36.49657,34.32846,41.7964,6.62479,11.32237,5.29983, 
 1.08406,2.16811,52.27562,4.09532,26.37871,21.19933,35.77387,26.25826, 
 7.10659,14.21319,7.22704,9.39516,13.85183,4.21578,8.91335,0, 
 4.33623,7.22704,14.33364,1.20451,22.28338,7.22704,3.61352,0.4818, 
 1.80676,36.97837,0,0,0,3.37262,12.88823)

# Create a matrix with one column of S_5 values.
mS_5 <- matrix(dblHistoricalValues_S_5,
		ncol=1,
		dimnames=list(c(1:length(dblHistoricalValues_S_5)),c("S_5")))

# Create a time series from the matrix.
tsS_5 <- ts(mS_5,start=c(1980,1),frequency=12)

# Make an S-5 autobox object with retained data.
objS_5_retained <- autobox(tsS_5,
			 iDataType=c(0),
			 iObjective=c(0,0,0),
			 iNumberOfRetainedValues=10,
			 iNumberOfForecastValues=10,
			 cPath=".\\Output")

# Run the calculation.
objS_5_retained <- autoboxRun(objS_5_retained)

# Print the status.
print(objS_5_retained$cStatus)

# Print the results
# The selection parameter selects the values to print:
# a = Actual,
# c = Cleansed (Adjusted),
# e = Equations,
# f = Forecast,
# h = Historical,
# i = Interventions,
# r = Residual,
# s = Statistics,
# t = Fitted.
autoboxPrint(objS_5_retained,selection="acefhirst")

# Plot the result.
# The selection parameter selects the values to plot:
# a = Actual,
# c = Cleansed (Adjusted),
# f = Forecast,
# h = Historical,
# i = Interventions,
# n = Retained,
# r = Residual,
# t = Fitted,
# u = Future.
autoboxPlot(objS_5_retained,selection="acfhinrtu")

# Unload the autobox library.
unloadNamespace("autobox")

# Restore the working directory.
setwd(saveWd)
